==> aws-cdk.aws-globalaccelerator-endpoints-1.138.2.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_globalaccelerator_endpoints_NetworkLoadBalancerEndpointProps(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_CfnEipEndpointProps(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpointOptions(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpointProps(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_CfnEipEndpoint(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpoint(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpoint(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_NetworkLoadBalancerEndpoint(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_globalaccelerator_endpoints_NetworkLoadBalancerEndpointProps, _aws_cdk_aws_globalaccelerator_endpoints_CfnEipEndpointProps, _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpointOptions, _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpointProps, _aws_cdk_aws_globalaccelerator_endpoints_CfnEipEndpoint, _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpoint, _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpoint, _aws_cdk_aws_globalaccelerator_endpoints_NetworkLoadBalancerEndpoint };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-globalaccelerator-endpoints-1.142.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_globalaccelerator_endpoints_NetworkLoadBalancerEndpointProps(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_CfnEipEndpointProps(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpointOptions(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpointProps(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpoint(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_NetworkLoadBalancerEndpoint(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpoint(p) {
}
function _aws_cdk_aws_globalaccelerator_endpoints_CfnEipEndpoint(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_globalaccelerator_endpoints_NetworkLoadBalancerEndpointProps, _aws_cdk_aws_globalaccelerator_endpoints_CfnEipEndpointProps, _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpointOptions, _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpointProps, _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpoint, _aws_cdk_aws_globalaccelerator_endpoints_NetworkLoadBalancerEndpoint, _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpoint, _aws_cdk_aws_globalaccelerator_endpoints_CfnEipEndpoint };
module.exports.DeprecationError = DeprecationError;
